pub struct Header { /* private fields */ }Expand description
DNS message header.
Implementations
Sourceimpl Header
impl Header
Sourcepub fn flags_mut(&mut self) -> &mut Flags
pub fn flags_mut(&mut self) -> &mut Flags
Returns a mutable reference to the flags for in-place modification.
Sourcepub const fn question_count(&self) -> u16
pub const fn question_count(&self) -> u16
Returns the number of questions.
Sourcepub const fn answer_count(&self) -> u16
pub const fn answer_count(&self) -> u16
Returns the number of answer records.
Returns the number of authority records.
Sourcepub const fn additional_count(&self) -> u16
pub const fn additional_count(&self) -> u16
Returns the number of additional records.
Sourcepub const fn set_question_count(&mut self, v: u16) -> &mut Header
pub const fn set_question_count(&mut self, v: u16) -> &mut Header
Sets the number of questions.
Sourcepub const fn set_answer_count(&mut self, v: u16) -> &mut Header
pub const fn set_answer_count(&mut self, v: u16) -> &mut Header
Sets the number of answer records.
Sets the number of authority records.
Sourcepub const fn set_additional_count(&mut self, v: u16) -> &mut Header
pub const fn set_additional_count(&mut self, v: u16) -> &mut Header
Sets the number of additional records.
Sourcepub const fn with_flags(self, v: Flags) -> Header
pub const fn with_flags(self, v: Flags) -> Header
Returns a header with the flags set.
Sourcepub const fn with_question_count(self, v: u16) -> Header
pub const fn with_question_count(self, v: u16) -> Header
Returns a header with the number of questions set.
Sourcepub const fn with_answer_count(self, v: u16) -> Header
pub const fn with_answer_count(self, v: u16) -> Header
Returns a header with the number of answer records set.
Returns a header with the number of authority records set.
Sourcepub const fn with_additional_count(self, v: u16) -> Header
pub const fn with_additional_count(self, v: u16) -> Header
Returns a header with the number of additional records set.
Sourcepub fn try_parse(buf: &[u8]) -> Result<(Header, &[u8]), ParseError>
pub fn try_parse(buf: &[u8]) -> Result<(Header, &[u8]), ParseError>
Parse a 12-byte DNS header from the start of buf. Returns the header
and a slice of the bytes following it.
Sourcepub fn write(&self, out: &mut [u8]) -> Result<usize, EncodeError>
pub fn write(&self, out: &mut [u8]) -> Result<usize, EncodeError>
Write a 12-byte DNS header into the start of out. Returns the number
of bytes written (always HEADER_SIZE on success).